import request from '@/utils/request'
import { praseStrEmpty } from '@/utils/common'
import Qs from 'qs'

/**
 * 1.新增用户
 * 2.修改用户
 * 3.删除用户
 * 4.查询用户列表
 * 5.导入用户信息
 * 6.导出用户
 * 7.下载用户导入模板
 * -----------------------------
 * 8.查询用户详细
 * 9.用户密码重置
 * 10.用户状态修改
 * 11.查询用户个人信息
 * 12.修改用户个人信息
 * 13.用户密码修改
 * 14.用户头像上传
 * 15.下载错误文件
 * */

// 1.新增用户
export function addUser(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/user/add',
    method: 'post',
    data,
    headers: {}
  })
}
// 2.修改用户
export function updateUser(data) {
  // const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/system/user/update',
    method: 'put',
    data: data,
    headers: {}
  })
}
// 3.删除用户
export function delUser(userId) {
  return request({
    url: '/system/user/deleteLogical/' + userId,
    method: 'delete'
  })
}
// 4.查询用户列表
export function listUser(query) {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  })
}

// 5.导入用户信息
export function importExcel(data) {
  return request({
    url: '/system/user/importExcel',
    method: 'post',
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    transformRequest: [(data) => {
      return data
    }],
    data
  })
}

// 6.导出用户
export function exportUser(query) {
  return request({
    url: '/system/user/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}
// 7.下载用户导入模板
export function importTemplate(params) {
  return request({
    url: '/system/user/importTemplate',
    method: 'get',
    responseType: 'blob',
    params
  })
}

// 8.查询用户详细
export function getUser(userId) {
  return request({
    url: '/system/user/' + praseStrEmpty(userId),
    method: 'get'
  })
}

// 9.用户密码重置
export function resetUserPwd(businessId, password) {
  const data = {
    businessId,
    password
  }
  return request({
    url: '/system/user/resetPassword',
    method: 'put',
    params: data
  })
}

// 10.用户状态修改
export function changeUserStatus(businessId, flag) {
  const data = {
    businessId,
    flag
  }
  return request({
    url: '/system/user/changeStatus',
    method: 'put',
    params: data
  })
}

// 11.查询用户个人信息
export function getUserProfile() {
  return request({
    url: '/system/user/profile',
    method: 'get'
  })
}

// 12.修改用户个人信息
export function updateUserProfile(data) {
  return request({
    url: 'system/user/profile',
    method: 'put',
    data: data
  })
}

// 13.用户密码修改
export function updateUserPwd(data) {
  return request({
    url: '/system/user/updatePwd',
    method: 'put',
    params: data
  })
}

// 14.用户头像上传
export function uploadAvatar(data) {
  return request({
    url: '/system/user/profile/avatar',
    method: 'post',
    data: data
  })
}

// 15.下载错误文件
export function uploadFalseFile(params) {
  params = Qs.stringify(params)
  return request({
    url: '/system/user/downFalseFile',
    method: 'post',
    data: params,
    responseType: 'blob'
  })
}
